# @api private
class foreman::config::ipa {
  if $facts['os']['selinux']['enabled'] {
    selboolean { ['allow_httpd_mod_auth_pam', 'httpd_dbus_sssd']:
      persistent => true,
      value      => 'on',
    }
  }

  file { "/etc/pam.d/${foreman::pam_service}":
    ensure  => file,
    owner   => root,
    group   => root,
    mode    => '0644',
    content => template('foreman/pam_service.erb'),
  }

  $http_keytab = pick($foreman::http_keytab, "${apache::conf_dir}/http.keytab")

  exec { 'ipa-getkeytab':
    command => "/bin/echo Get keytab \
      && KRB5CCNAME=KEYRING:session:get-http-service-keytab kinit -k \
      && KRB5CCNAME=KEYRING:session:get-http-service-keytab /usr/sbin/ipa-getkeytab -k ${http_keytab} -p HTTP/${facts['networking']['fqdn']} \
      && kdestroy -c KEYRING:session:get-http-service-keytab",
    creates => $http_keytab,
  }
  -> file { $http_keytab:
    ensure => file,
    owner  => $apache::user,
    mode   => '0600',
  }

  $gssapi_local_name = bool2str($foreman::gssapi_local_name, 'On', 'Off')

  foreman::config::apache::fragment { 'intercept_form_submit':
    ssl_content => template('foreman/intercept_form_submit.conf.erb'),
  }

  foreman::config::apache::fragment { 'lookup_identity':
    ssl_content => template('foreman/lookup_identity.conf.erb'),
  }

  foreman::config::apache::fragment { 'auth_gssapi':
    ssl_content => template('foreman/auth_gssapi.conf.erb'),
  }

  foreman::config::apache::fragment { 'external_auth_api':
    ssl_content => template('foreman/external_auth_api.conf.erb'),
  }

  if $foreman::ipa_manage_sssd {
    $sssd = pick(fact('foreman_sssd'), {})
    $sssd_services = join(unique(pick($sssd['services'], []) + ['ifp']), ', ')
    $sssd_ldap_user_extra_attrs = join(unique(pick($sssd['ldap_user_extra_attrs'], []) + ['email:mail', 'lastname:sn', 'firstname:givenname']), ', ')
    $sssd_allowed_uids = join(unique(pick($sssd['allowed_uids'], []) + [$apache::user, 'root']), ', ')
    $sssd_user_attributes = join(unique(pick($sssd['user_attributes'], []) + ['+email', '+firstname', '+lastname']), ', ')
    $sssd_ifp_extra_attributes = [
      "set target[.=~regexp('domain/.*')]/ldap_user_extra_attrs '${sssd_ldap_user_extra_attrs}'",
      "set target[.='sssd']/services '${sssd_services}'",
      'set target[.=\'ifp\'] \'ifp\'',
      "set target[.='ifp']/allowed_uids '${sssd_allowed_uids}'",
      "set target[.='ifp']/user_attributes '${sssd_user_attributes}'",
    ]

    $sssd_changes = $sssd_ifp_extra_attributes + ($foreman::ipa_sssd_default_realm ? {
        undef => [],
        default => ["set target[.='sssd']/default_domain_suffix '${$foreman::ipa_sssd_default_realm}'"],
    })

    augeas { 'sssd-ifp-extra-attributes':
      context => '/files/etc/sssd/sssd.conf',
      changes => $sssd_changes,
      notify  => Service['sssd'],
    }

    service { 'sssd':
      ensure  => running,
      enable  => true,
      require => Package['sssd-dbus'],
    }
  }
}
